@@ -23,6 +23,7 @@
 #include <QtGlobal>
 #include <QSettings>
 #include <QProcess>
+#include <QTextStream>
 
 
 class Gui : public QWidget, public Ui::Gui {
@@ -45,6 +46,7 @@ class Gui : public QWidget, public Ui::Gui {
       QString        program1, program2;
       bool           process2Started;
       bool           aborted;
+      QTextStream    *myOutput;
 
      private slots:
       void currentDateAndTime(); //for the current minimum date and time
