@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,11 @@
 #ifndef CH_PASSWD_H
 #define CH_PASSWD_H
 
-#include <QtGui>
 #include "ui_ch_passwd.h"
 
+#include <QMessageBox>
+#include <QSettings>
+
 class ChangePassword : public QDialog, public Ui::ChangePassword {
     Q_OBJECT
  
