@@ -49,7 +49,8 @@ Editor::~Editor(){ delete confFile; }
 void Editor::showEvent(QShowEvent* show_editor){
      isClosed = false;
      if(!confFile->open(QIODevice::ReadWrite | QIODevice::Text)){
-       qCritical("E: Can not open qshutdown.conf!");
+       QTextStream myOutput(stdout);
+       myOutput << "E: Can not open qshutdown.conf!" << endl;
        return;
      }
      QString text;                      //reading content of qshutdown.conf
@@ -60,13 +61,13 @@ void Editor::showEvent(QShowEvent* show_editor){
 
      starting();
 
-     QDialog::showEvent(show_editor);
+     QWidget::showEvent(show_editor);
 }
 
-void Editor::closeEvent(QCloseEvent* window_close){
+void Editor::closeEvent(QCloseEvent* close_editor){
      isClosed = true;
      finishing();
-     QDialog::closeEvent(window_close);
+     QWidget::closeEvent(close_editor);
 }
 
 bool Editor::getClosed(){ return isClosed; }
@@ -90,7 +91,8 @@ void Editor::keyPressEvent(QKeyEvent *kEvent){
 
 void Editor::saveChanges(){
      if(!confFile->open(QIODevice::ReadWrite | QIODevice::Text)){
-       qCritical("E: Can not open qshutdown.conf!");
+       QTextStream myOutput(stdout);
+       myOutput << "E: Can not open qshutdown.conf!";
        return;
      }
      QString newContent;                //writing content of editor to qshutdown.conf
