@@ -22,11 +22,14 @@
 #endif
 
 #include <QProcess>
+#include <QTextStream>
 
 extern bool verbose;
 
 namespace Power{
 
+QTextStream oput(stdout);
+
 bool lockMyScreen;
 
 void shutdown(){
@@ -46,11 +49,13 @@ void shutdown(){
      response = gnomeSessionManager.call("RequestShutdown");
      if(response.type() == QDBusMessage::ErrorMessage){
        if(verbose)
-         qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
        g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh shutdown");
        g_pwr2 = QProcess::startDetached("gnome-power-cmd shutdown");
        if(verbose && !g_pwr1 && !g_pwr2)
-           qWarning() << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work";
+           oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
+                << endl;
      }
      else
        g = true;
@@ -61,7 +66,8 @@ void shutdown(){
        response = kdeSessionManager.call("logout", 0, 2, 2);
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          k = true;
@@ -75,7 +81,8 @@ void shutdown(){
        response = powermanagement.call("Shutdown");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          hal = true;
@@ -88,7 +95,8 @@ void shutdown(){
        response = powermanagement.call("Stop");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
          QProcess::startDetached("sudo shutdown -P now");
        }
      }
@@ -112,11 +120,13 @@ void reboot(){
      response = gnomeSessionManager.call("RequestReboot");
      if(response.type() == QDBusMessage::ErrorMessage){
        if(verbose)
-         qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
        g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh reboot");
        g_pwr2 = QProcess::startDetached("gnome-power-cmd reboot");
        if(verbose && !g_pwr1 && !g_pwr2)
-         qWarning() << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work";
+         oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
+              << endl;
      }
      else
        g = true;
@@ -127,7 +137,8 @@ void reboot(){
        response = kdeSessionManager.call("logout", 0, 2, 1);
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          k = true;
@@ -141,7 +152,8 @@ void reboot(){
        response = powermanagement.call("Reboot");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          hal = true;
@@ -154,7 +166,8 @@ void reboot(){
        response = powermanagement.call("Restart");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
          QProcess::startDetached("sudo shutdown -r now");
        }
      }
@@ -180,32 +193,37 @@ void suspend(){
        response = screenlock.call("Lock");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          lock_works = true;
 
        if(!lock_works){
          if(!QProcess::startDetached("gnome-screensaver-command -l")){
-           if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
+           if(verbose) oput << "W: gnome-screensaver-command -l didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock")){
-           if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
+           if(verbose) oput << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock")){
-           if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
+           if(verbose) oput << "W: dcop kdesktop KScreensaverIface lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("xscreensaver-command -lock")){
-           if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+           if(verbose) oput << "W: xscreensaver-command -lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
@@ -214,7 +232,8 @@ void suspend(){
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh suspend");
      g_pwr2 = QProcess::startDetached("gnome-power-cmd suspend");
      if(!g_pwr1 && !g_pwr2 && verbose)
-       qWarning() << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work";
+       oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
+            << endl;
 
      if(!g_pwr1 && !g_pwr2){
        QDBusInterface powermanagement("org.freedesktop.Hal",
@@ -224,7 +243,8 @@ void suspend(){
        response = powermanagement.call("Suspend",0);
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          hal = true;
@@ -237,7 +257,8 @@ void suspend(){
        response = powermanagement.call("Suspend");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          upower = true;
@@ -250,7 +271,8 @@ void suspend(){
        response = powermanagement.call("Suspend");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
      }
    #endif
@@ -275,32 +297,37 @@ void hibernate(){
        response = screenlock.call("Lock");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          lock_works = true;
 
        if(!lock_works){
          if(!QProcess::startDetached("gnome-screensaver-command -l")){
-           if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
+           if(verbose) oput << "W: gnome-screensaver-command -l didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock")){
-           if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
+           if(verbose) oput << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock")){
-           if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
+           if(verbose) oput << "W: dcop kdesktop KScreensaverIface lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
        if(!lock_works){
          if(!QProcess::startDetached("xscreensaver-command -lock")){
-           if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+           if(verbose) oput << "W: xscreensaver-command -lock didn't work"
+                            << endl;
           }
 	  else lock_works = true;
         }
@@ -309,7 +336,8 @@ void hibernate(){
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh hibernate");
      g_pwr2 = QProcess::startDetached("gnome-power-cmd hibernate");
      if(!g_pwr1 && !g_pwr2 && verbose)
-       qWarning() << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work";
+       oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
+            << endl;
 
      if(!g_pwr1 && !g_pwr2){
        QDBusInterface powermanagement("org.freedesktop.Hal",
@@ -319,7 +347,8 @@ void hibernate(){
        response = powermanagement.call("Hibernate");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          hal = true;
@@ -332,7 +361,8 @@ void hibernate(){
        response = powermanagement.call("Hibernate");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
        else
          upower = true;
@@ -344,7 +374,8 @@ void hibernate(){
        response = powermanagement.call("Hibernate");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
-           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+           oput << "W: " << response.errorName() << ": "
+                << response.errorMessage() << endl;
        }
      }
    #endif
