@@ -48,9 +48,11 @@ class Preferences : public QDialog, public Ui::Preferences {
      void fontSize1Changed(int f1);
      void fontSize2Changed(int f2);
      void fontSize3Changed(int f3);
-     void autostartFile();
      void lockScreen();
 
+    public slots:
+     void autostartFile();
+
     signals:
      void starting();
      void finishing();
@@ -59,7 +61,7 @@ class Preferences : public QDialog, public Ui::Preferences {
 
     protected:
      virtual void showEvent(QShowEvent* show_pref);
-     virtual void closeEvent(QCloseEvent* window_close);
+     virtual void closeEvent(QCloseEvent* close_pref);
 };
 
 #endif //PREFERENCES_H
